@@ -23,9 +23,9 @@ from torch.optim import Optimizer
 from torch.utils.data import DataLoader
 
 from lightning_fabric.plugins import Precision
-from lightning_fabric.plugins.precision.utils import _convert_fp_tensor
 from lightning_fabric.strategies import Strategy
 from lightning_fabric.utilities import move_data_to_device
+from lightning_fabric.utilities.data import _set_sampler_epoch
 from lightning_fabric.utilities.device_dtype_mixin import _DeviceDtypeModuleMixin
 from lightning_fabric.utilities.types import Optimizable
 
@@ -104,14 +104,12 @@ class _FabricModule(_DeviceDtypeModuleMixin):
     def forward(self, *args: Any, **kwargs: Any) -> Any:
         """Casts all inputs to the right precision and handles autocast for operations in the module forward
         method."""
-        args, kwargs = apply_to_collection([args, kwargs], function=self._precision.convert_input, dtype=Tensor)
+        args, kwargs = self._precision.convert_input((args, kwargs))
 
         with self._precision.forward_context():
             output = self._forward_module(*args, **kwargs)
 
-        output = apply_to_collection(
-            output, function=_convert_fp_tensor, dtype=Tensor, dst_type=torch.get_default_dtype()
-        )
+        output = self._precision.convert_output(output)
         return output
 
     @overload
@@ -168,20 +166,17 @@ class _FabricDataLoader:
         return len(self._dataloader)
 
     def __iter__(self) -> Union[Iterator[Any], Generator[Any, None, None]]:
-        if hasattr(self._dataloader.sampler, "set_epoch"):
-            # Without setting the epoch, the distributed sampler would return the same indices every time, even when
-            # shuffling is enabled. In PyTorch, the user would normally have to call `.set_epoch()` on the sampler.
-            # In Lite, we take care of this boilerplate code.
-            self._dataloader.sampler.set_epoch(self._num_iter_calls)
+        # Without setting the epoch, the distributed sampler would return the same indices every time, even when
+        # shuffling is enabled. In PyTorch, the user would normally have to call `.set_epoch()` on the sampler.
+        # In Fabric, we take care of this boilerplate code.
+        _set_sampler_epoch(self._dataloader, self._num_iter_calls)
         self._num_iter_calls += 1
 
-        iterator = iter(self._dataloader)
         if self._device is None:
-            yield from iterator
-            return
-
-        for item in iterator:
-            yield move_data_to_device(item, self._device)
+            yield from iter(self._dataloader)
+        else:
+            for item in self._dataloader:
+                yield move_data_to_device(item, self._device)
 
 
 def _process_optimizer_zero_grad_kwargs(optimizer: Optimizer, kwargs: Dict[str, Any]) -> Dict[str, Any]:
@@ -189,3 +184,31 @@ def _process_optimizer_zero_grad_kwargs(optimizer: Optimizer, kwargs: Dict[str,
         # Some optimizers out there, for example DeepSpeedZeroOptimizer, use a different name than PyTorch
         kwargs["set_grads_to_None"] = kwargs.pop("set_to_none")
     return kwargs
+
+
+def _unwrap_objects(collection: Any) -> Any:
+    def _unwrap(
+        obj: Union[_FabricModule, _FabricOptimizer, _FabricDataLoader]
+    ) -> Union[nn.Module, Optimizer, DataLoader]:
+        if isinstance(obj, _FabricModule):
+            return obj._forward_module
+        if isinstance(obj, _FabricOptimizer):
+            return obj.optimizer
+        if isinstance(obj, _FabricDataLoader):
+            return obj._dataloader
+        return obj
+
+    return apply_to_collection(collection, dtype=(_FabricModule, _FabricOptimizer, _FabricDataLoader), function=_unwrap)
+
+
+def is_wrapped(obj: object) -> bool:
+    """Checks if an object was set up by Fabric.
+
+    A :class:`~torch.nn.Module` may be wrapped by a :class:`_FabricModule`, a :class:`~torch.optim.Optimizer`
+    may be wrapped by a :class:`_FabricOptimizer`, or a :class:`~torch.utils.data.DataLoader` may be wrapped by
+    :class:`_FabricDataLoader`.
+
+    Args:
+        obj: The object to test.
+    """
+    return isinstance(obj, (_FabricModule, _FabricOptimizer, _FabricDataLoader))
