@@ -14,31 +14,17 @@
 from abc import ABC
 from typing import Any, Dict
 
-import torch
-
 import pytorch_lightning as pl
 from lightning_fabric.accelerators.accelerator import Accelerator as _Accelerator
 from lightning_fabric.utilities.types import _DEVICE
-from pytorch_lightning.utilities.rank_zero import rank_zero_deprecation
 
 
 class Accelerator(_Accelerator, ABC):
     """The Accelerator base class for Lightning PyTorch.
 
-    An Accelerator is meant to deal with one type of hardware.
+    .. warning::  Writing your own accelerator is an :ref:`experimental <versioning:Experimental API>` feature.
     """
 
-    def setup_environment(self, root_device: torch.device) -> None:
-        """
-        .. deprecated:: v1.8.0
-            This hook was deprecated in v1.8.0 and will be removed in v2.0.0. Please use ``setup_device()`` instead.
-        """
-        rank_zero_deprecation(
-            "`Accelerator.setup_environment` has been deprecated in deprecated in v1.8.0 and will be removed in"
-            " v2.0.0. Please use `setup_device()` instead."
-        )
-        self.setup_device(root_device)
-
     def setup(self, trainer: "pl.Trainer") -> None:
         """Setup plugins for the trainer fit and creates optimizers.
 
