@@ -1,4 +1,4 @@
-# Copyright The PyTorch Lightning team.
+# Copyright The Lightning AI team.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -20,9 +20,9 @@ from typing import Any, Dict, List, Optional, Union
 import torch
 
 import pytorch_lightning as pl
-from lightning_lite.accelerators.cuda import num_cuda_devices
-from lightning_lite.utilities.device_parser import _parse_gpu_ids
-from lightning_lite.utilities.types import _DEVICE
+from lightning_fabric.accelerators.cuda import _check_cuda_matmul_precision, _clear_cuda_memory, num_cuda_devices
+from lightning_fabric.utilities.device_parser import _parse_gpu_ids
+from lightning_fabric.utilities.types import _DEVICE
 from pytorch_lightning.accelerators.accelerator import Accelerator
 from pytorch_lightning.utilities.exceptions import MisconfigurationException
 
@@ -40,13 +40,13 @@ class CUDAAccelerator(Accelerator):
         """
         if device.type != "cuda":
             raise MisconfigurationException(f"Device should be GPU, got {device} instead")
+        _check_cuda_matmul_precision(device)
         torch.cuda.set_device(device)
 
     def setup(self, trainer: "pl.Trainer") -> None:
         # TODO refactor input from trainer to local_rank @four4fish
         self.set_nvidia_flags(trainer.local_rank)
-        # clear cache before training
-        torch.cuda.empty_cache()
+        _clear_cuda_memory()
 
     @staticmethod
     def set_nvidia_flags(local_rank: int) -> None:
@@ -72,8 +72,7 @@ class CUDAAccelerator(Accelerator):
         return torch.cuda.memory_stats(device)
 
     def teardown(self) -> None:
-        # clean up memory
-        torch.cuda.empty_cache()
+        _clear_cuda_memory()
 
     @staticmethod
     def parse_devices(devices: Union[int, str, List[int]]) -> Optional[List[int]]:
