@@ -1,4 +1,4 @@
-# Copyright The PyTorch Lightning team.
+# Copyright The Lightning AI team.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -21,10 +21,9 @@ Monitors and logs device stats during training.
 from typing import Any, Dict, Optional
 
 import pytorch_lightning as pl
+from pytorch_lightning.accelerators.cpu import _PSUTIL_AVAILABLE
 from pytorch_lightning.callbacks.callback import Callback
 from pytorch_lightning.utilities.exceptions import MisconfigurationException
-from pytorch_lightning.utilities.imports import _PSUTIL_AVAILABLE
-from pytorch_lightning.utilities.rank_zero import rank_zero_warn
 from pytorch_lightning.utilities.types import STEP_OUTPUT
 
 
@@ -36,14 +35,14 @@ class DeviceStatsMonitor(Callback):
 
     Args:
         cpu_stats: if ``None``, it will log CPU stats only if the accelerator is CPU.
-            It will raise a warning if ``psutil`` is not installed till v1.9.0.
-            If ``True``, it will log CPU stats regardless of the accelerator, and it will
-            raise an exception if ``psutil`` is not installed.
+            If ``True``, it will log CPU stats regardless of the accelerator.
             If ``False``, it will not log CPU stats regardless of the accelerator.
 
     Raises:
         MisconfigurationException:
             If ``Trainer`` has no logger.
+        ModuleNotFoundError:
+            If ``psutil`` is not installed and CPU stats are monitored.
 
     Example:
         >>> from pytorch_lightning import Trainer
@@ -70,13 +69,9 @@ class DeviceStatsMonitor(Callback):
         # warn in setup to warn once
         device = trainer.strategy.root_device
         if self._cpu_stats is None and device.type == "cpu" and not _PSUTIL_AVAILABLE:
-            # TODO: raise an exception from v1.9
-            rank_zero_warn(
-                "`DeviceStatsMonitor` will not log CPU stats as `psutil` is not installed."
-                " To install `psutil`, run `pip install psutil`."
-                " It will raise an exception if `psutil` is not installed post v1.9.0."
+            raise ModuleNotFoundError(
+                f"`DeviceStatsMonitor` cannot log CPU stats as `psutil` is not installed. {str(_PSUTIL_AVAILABLE)} "
             )
-            self._cpu_stats = False
 
     def _get_and_log_device_stats(self, trainer: "pl.Trainer", key: str) -> None:
         if not trainer._logger_connector.should_update_logs:
@@ -111,7 +106,12 @@ class DeviceStatsMonitor(Callback):
         self._get_and_log_device_stats(trainer, "on_train_batch_end")
 
     def on_validation_batch_start(
-        self, trainer: "pl.Trainer", pl_module: "pl.LightningModule", batch: Any, batch_idx: int, dataloader_idx: int
+        self,
+        trainer: "pl.Trainer",
+        pl_module: "pl.LightningModule",
+        batch: Any,
+        batch_idx: int,
+        dataloader_idx: int = 0,
     ) -> None:
         self._get_and_log_device_stats(trainer, "on_validation_batch_start")
 
@@ -122,12 +122,17 @@ class DeviceStatsMonitor(Callback):
         outputs: Optional[STEP_OUTPUT],
         batch: Any,
         batch_idx: int,
-        dataloader_idx: int,
+        dataloader_idx: int = 0,
     ) -> None:
         self._get_and_log_device_stats(trainer, "on_validation_batch_end")
 
     def on_test_batch_start(
-        self, trainer: "pl.Trainer", pl_module: "pl.LightningModule", batch: Any, batch_idx: int, dataloader_idx: int
+        self,
+        trainer: "pl.Trainer",
+        pl_module: "pl.LightningModule",
+        batch: Any,
+        batch_idx: int,
+        dataloader_idx: int = 0,
     ) -> None:
         self._get_and_log_device_stats(trainer, "on_test_batch_start")
 
@@ -138,7 +143,7 @@ class DeviceStatsMonitor(Callback):
         outputs: Optional[STEP_OUTPUT],
         batch: Any,
         batch_idx: int,
-        dataloader_idx: int,
+        dataloader_idx: int = 0,
     ) -> None:
         self._get_and_log_device_stats(trainer, "on_test_batch_end")
 
