@@ -1,4 +1,4 @@
-# Copyright The PyTorch Lightning team.
+# Copyright The Lightning AI team.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -21,10 +21,11 @@ from torch import optim
 from torch.optim import Optimizer
 
 import pytorch_lightning as pl
+from lightning_fabric.utilities.types import _Stateful, Optimizable, ReduceLROnPlateau
 from pytorch_lightning.utilities.exceptions import MisconfigurationException
 from pytorch_lightning.utilities.model_helpers import is_overridden
 from pytorch_lightning.utilities.rank_zero import rank_zero_warn
-from pytorch_lightning.utilities.types import _Stateful, LRSchedulerConfig, LRSchedulerTypeTuple, ReduceLROnPlateau
+from pytorch_lightning.utilities.types import LRSchedulerConfig, LRSchedulerTypeTuple
 
 
 def do_nothing_closure() -> None:
@@ -39,20 +40,10 @@ class LightningOptimizer:
         # copy most of the `Optimizer` methods into this instance. `__del__` is skipped in case the optimizer has
         # implemented custom logic which we would not want to call on destruction of the `LightningOptimizer`
         self.__dict__ = {k: v for k, v in optimizer.__dict__.items() if k not in ("step", "__del__")}
-
-        # For Horovod
-        if hasattr(optimizer, "skip_synchronize"):
-            self.__class__ = type(
-                "Lightning" + optimizer.__class__.__name__, (self.__class__, optimizer.__class__.__bases__[0]), {}
-            )
-            self.skip_synchronize = optimizer.skip_synchronize
-            self.synchronize = optimizer.synchronize
-        else:
-            self.__class__ = type("Lightning" + optimizer.__class__.__name__, (self.__class__, optimizer.__class__), {})
+        self.__class__ = type("Lightning" + optimizer.__class__.__name__, (self.__class__, optimizer.__class__), {})
 
         self._optimizer = optimizer
         self._strategy: Optional[pl.strategies.Strategy] = None
-        self._optimizer_idx = 0
         # to inject logic around the optimizer step, particularly useful with manual optimization
         self._on_before_step = do_nothing_closure
         self._on_after_step = do_nothing_closure
@@ -63,7 +54,7 @@ class LightningOptimizer:
 
     @classmethod
     def _to_lightning_optimizer(
-        cls, optimizer: Union[Optimizer, "LightningOptimizer"], strategy: "pl.strategies.Strategy", opt_idx: int
+        cls, optimizer: Union[Optimizer, "LightningOptimizer"], strategy: "pl.strategies.Strategy"
     ) -> "LightningOptimizer":
         if isinstance(optimizer, LightningOptimizer):
             # the user could return a `LightningOptimizer` from `configure_optimizers`, see test:
@@ -72,7 +63,6 @@ class LightningOptimizer:
         else:
             lightning_optimizer = cls(optimizer)
         lightning_optimizer._strategy = proxy(strategy)
-        lightning_optimizer._optimizer_idx = opt_idx
         return lightning_optimizer
 
     @contextmanager
@@ -93,9 +83,9 @@ class LightningOptimizer:
         lightning_module = self._strategy.lightning_module
         assert lightning_module is not None
         with _block_parallel_sync_behavior(self._strategy, block=(not sync_grad)):
-            lightning_module.toggle_optimizer(self, self._optimizer_idx)
+            lightning_module.toggle_optimizer(self)
             yield
-            lightning_module.untoggle_optimizer(self._optimizer_idx)
+            lightning_module.untoggle_optimizer(self)
 
     def step(self, closure: Optional[Callable[[], Any]] = None, **kwargs: Any) -> Any:
         """Performs a single optimization step (parameter update).
@@ -110,7 +100,7 @@ class LightningOptimizer:
         Example::
 
             # Scenario for a GAN using manual optimization
-            def training_step(...):
+            def training_step(self, batch, batch_idx):
                 opt_gen, opt_dis = self.optimizers()
 
                 ...
@@ -132,7 +122,7 @@ class LightningOptimizer:
 
 
             # A more advanced example
-            def training_step(self, batch, batch_idx, ...):
+            def training_step(self, batch, batch_idx):
                 opt_gen, opt_dis = self.optimizers()
 
                 ...
@@ -165,7 +155,7 @@ class LightningOptimizer:
             raise MisconfigurationException("When `optimizer.step(closure)` is called, the closure should be callable")
 
         assert self._strategy is not None
-        step_output = self._strategy.optimizer_step(self._optimizer, self._optimizer_idx, closure, **kwargs)
+        step_output = self._strategy.optimizer_step(self._optimizer, closure, **kwargs)
 
         self._on_after_step()
 
@@ -174,9 +164,11 @@ class LightningOptimizer:
 
 def _init_optimizers_and_lr_schedulers(
     model: "pl.LightningModule",
-) -> Tuple[List[Optimizer], List[LRSchedulerConfig], List[int]]:
+) -> Tuple[List[Optimizer], List[LRSchedulerConfig]]:
     """Calls `LightningModule.configure_optimizers` and parses and validates the output."""
-    optim_conf = model.trainer._call_lightning_module_hook("configure_optimizers", pl_module=model)
+    from pytorch_lightning.trainer import call
+
+    optim_conf = call._call_lightning_module_hook(model.trainer, "configure_optimizers", pl_module=model)
 
     if optim_conf is None:
         rank_zero_warn(
@@ -184,32 +176,33 @@ def _init_optimizers_and_lr_schedulers(
         )
         optim_conf = _MockOptimizer()
 
-    optimizers, lr_schedulers, optimizer_frequencies, monitor = _configure_optimizers(optim_conf)
+    optimizers, lr_schedulers, monitor = _configure_optimizers(optim_conf)
     lr_scheduler_configs = (
         _configure_schedulers_automatic_opt(lr_schedulers, monitor)
         if model.automatic_optimization
         else _configure_schedulers_manual_opt(lr_schedulers)
     )
-    _set_scheduler_opt_idx(optimizers, lr_scheduler_configs)
+    _validate_multiple_optimizers_support(optimizers, model)
+    _validate_optimizers_attached(optimizers, lr_scheduler_configs)
     _validate_scheduler_api(lr_scheduler_configs, model)
-    return optimizers, lr_scheduler_configs, optimizer_frequencies
+    return optimizers, lr_scheduler_configs
 
 
 def _configure_optimizers(
     optim_conf: Union[Dict[str, Any], List, Optimizer, Tuple]
-) -> Tuple[List, List, List, Optional[str]]:
-    optimizers, lr_schedulers, optimizer_frequencies = [], [], []
+) -> Tuple[List, List, Optional[str]]:
+    optimizers, lr_schedulers = [], []
     monitor = None
 
     # single output, single optimizer
-    if isinstance(optim_conf, Optimizer):
+    if isinstance(optim_conf, Optimizable):
         optimizers = [optim_conf]
     # two lists, optimizer + lr schedulers
     elif (
         isinstance(optim_conf, (list, tuple))
         and len(optim_conf) == 2
         and isinstance(optim_conf[0], list)
-        and all(isinstance(opt, Optimizer) for opt in optim_conf[0])
+        and all(isinstance(opt, Optimizable) for opt in optim_conf[0])
     ):
         opt, sch = optim_conf
         optimizers = opt
@@ -225,25 +218,12 @@ def _configure_optimizers(
         for opt_dict in optim_conf:
             _validate_optim_conf(opt_dict)
         optimizers = [opt_dict["optimizer"] for opt_dict in optim_conf]
-        scheduler_dict = (
-            lambda scheduler, opt_idx: dict(scheduler, opt_idx=opt_idx)
-            if isinstance(scheduler, dict)
-            else {"scheduler": scheduler, "opt_idx": opt_idx}
-        )
-
+        scheduler_dict = lambda scheduler: dict(scheduler) if isinstance(scheduler, dict) else {"scheduler": scheduler}
         lr_schedulers = [
-            scheduler_dict(opt_dict["lr_scheduler"], opt_idx)
-            for opt_idx, opt_dict in enumerate(optim_conf)
-            if "lr_scheduler" in opt_dict
+            scheduler_dict(opt_dict["lr_scheduler"]) for opt_dict in optim_conf if "lr_scheduler" in opt_dict
         ]
-        optimizer_frequencies = [
-            opt_dict["frequency"] for opt_dict in optim_conf if opt_dict.get("frequency", None) is not None
-        ]
-        # assert that if frequencies are present, they are given for all optimizers
-        if optimizer_frequencies and len(optimizer_frequencies) != len(optimizers):
-            raise ValueError("A frequency must be given to each optimizer.")
     # single list or tuple, multiple optimizer
-    elif isinstance(optim_conf, (list, tuple)) and all(isinstance(opt, Optimizer) for opt in optim_conf):
+    elif isinstance(optim_conf, (list, tuple)) and all(isinstance(opt, Optimizable) for opt in optim_conf):
         optimizers = list(optim_conf)
     # unknown configuration
     else:
@@ -252,11 +232,10 @@ def _configure_optimizers(
             " Output from `model.configure_optimizers()` should be one of:\n"
             " * `Optimizer`\n"
             " * [`Optimizer`]\n"
-            " * ([`Optimizer`], [`_LRScheduler`])\n"
-            ' * {"optimizer": `Optimizer`, (optional) "lr_scheduler": `_LRScheduler`}\n'
-            ' * A list of the previously described dict format, with an optional "frequency" key (int)'
+            " * ([`Optimizer`], [`LRScheduler`])\n"
+            ' * {"optimizer": `Optimizer`, (optional) "lr_scheduler": `LRScheduler`}\n'
         )
-    return optimizers, lr_schedulers, optimizer_frequencies, monitor
+    return optimizers, lr_schedulers, monitor
 
 
 def _configure_schedulers_automatic_opt(schedulers: list, monitor: Optional[str]) -> List[LRSchedulerConfig]:
@@ -321,7 +300,9 @@ def _configure_schedulers_manual_opt(schedulers: list) -> List[LRSchedulerConfig
     lr_scheduler_configs = []
     for scheduler in schedulers:
         if isinstance(scheduler, dict):
-            invalid_keys = {"interval", "frequency", "reduce_on_plateau", "monitor", "strict"}
+            # interval is not in this list even though the user needs to manually call the scheduler because
+            # the `LearningRateMonitor` callback needs to check its value to know when to log the learning rate
+            invalid_keys = {"reduce_on_plateau", "monitor", "strict"}
             keys_to_warn = [k for k in scheduler.keys() if k in invalid_keys]
 
             if keys_to_warn:
@@ -355,27 +336,25 @@ def _validate_scheduler_api(lr_scheduler_configs: List[LRSchedulerConfig], model
             )
 
 
-def _set_scheduler_opt_idx(optimizers: List[Optimizer], lr_scheduler_configs: List[LRSchedulerConfig]) -> None:
+def _validate_multiple_optimizers_support(optimizers: List[Optimizer], model: "pl.LightningModule") -> None:
+    if model.automatic_optimization and len(optimizers) > 1:
+        raise RuntimeError(
+            "Training with multiple optimizers is only supported with manual optimization. Set"
+            " `self.automatic_optimization = False`, then access your optimizers in `training_step` with"
+            " `opt1, opt2, ... = self.optimizers()`."
+        )
+
+
+def _validate_optimizers_attached(optimizers: List[Optimizer], lr_scheduler_configs: List[LRSchedulerConfig]) -> None:
     for config in lr_scheduler_configs:
-
-        for opt_idx, opt in enumerate(optimizers):
-            if config.scheduler.optimizer is opt:
-                if config.opt_idx is not None and config.opt_idx != opt_idx:
-                    raise MisconfigurationException(
-                        "`opt_idx` set inside scheduler config does not match with the index"
-                        " of the respective optimizer returned from `configure_optimizers`."
-                    )
-
-                config.opt_idx = opt_idx
-                break
-        else:
+        if config.scheduler.optimizer not in optimizers:
             raise MisconfigurationException(
                 "Some schedulers are attached with an optimizer that wasn't returned from `configure_optimizers`."
             )
 
 
 def _validate_optim_conf(optim_conf: Dict[str, Any]) -> None:
-    valid_keys = {"optimizer", "lr_scheduler", "frequency", "monitor"}
+    valid_keys = {"optimizer", "lr_scheduler", "monitor"}
     extra_keys = optim_conf.keys() - valid_keys
     if extra_keys:
         rank_zero_warn(
@@ -399,7 +378,7 @@ class _MockOptimizer(Optimizer):
     def state_dict(self) -> Dict[str, Any]:
         return {}  # Return Empty
 
-    def step(self, closure: Callable = None) -> None:
+    def step(self, closure: Optional[Callable] = None) -> None:
         if closure is not None:
             closure()
 
