@@ -1,4 +1,4 @@
-# Copyright The PyTorch Lightning team.
+# Copyright The Lightning AI team.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -39,6 +39,8 @@ class _MNIST(Dataset):
 
     We cannot import the tests as they are not distributed with the package.
     See https://github.com/Lightning-AI/lightning/pull/7614#discussion_r671183652 for more context.
+
+    .. warning::  This is meant for testing/debugging and is experimental.
     """
 
     RESOURCES = (
@@ -159,8 +161,6 @@ class MNISTDataModule(LightningDataModule):
         normalize: bool = False,
         seed: int = 42,
         batch_size: int = 32,
-        *args: Any,
-        **kwargs: Any,
     ) -> None:
         """
         Args:
@@ -171,7 +171,7 @@ class MNISTDataModule(LightningDataModule):
             seed: starting seed for RNG.
             batch_size: desired batch size.
         """
-        super().__init__(*args, **kwargs)
+        super().__init__()
         if num_workers and _IS_WINDOWS:
             # see: https://stackoverflow.com/a/59680818
             warn(
