@@ -1,4 +1,4 @@
-# Copyright The PyTorch Lightning team.
+# Copyright The Lightning AI team.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -15,16 +15,14 @@
 from concurrent.futures import ThreadPoolExecutor
 from typing import Any, Optional
 
-from lightning_lite.plugins import CheckpointIO
+from lightning_fabric.plugins import CheckpointIO
 from pytorch_lightning.plugins.io.wrapper import _WrappingCheckpointIO
 
 
 class AsyncCheckpointIO(_WrappingCheckpointIO):
     """``AsyncCheckpointIO`` enables saving the checkpoints asynchronously in a thread.
 
-    .. warning::
-
-        This is currently an experimental plugin/feature and API changes are to be expected.
+    .. warning::  This is an :ref:`experimental <versioning:Experimental API>` feature.
 
     Args:
         checkpoint_io: A checkpoint IO plugin that is used as the basis for async checkpointing.
