@@ -1,4 +1,4 @@
-# Copyright The PyTorch Lightning team.
+# Copyright The Lightning AI team.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -17,14 +17,17 @@ from typing import Any, Dict, Optional
 
 import torch
 
-from lightning_lite.plugins import TorchCheckpointIO
-from lightning_lite.utilities import move_data_to_device
-from lightning_lite.utilities.cloud_io import _atomic_save, get_filesystem
-from lightning_lite.utilities.types import _PATH
+from lightning_fabric.plugins import TorchCheckpointIO
+from lightning_fabric.utilities import move_data_to_device
+from lightning_fabric.utilities.cloud_io import _atomic_save, get_filesystem
+from lightning_fabric.utilities.types import _PATH
 
 
 class HPUCheckpointIO(TorchCheckpointIO):
-    """CheckpointIO to save checkpoints for HPU training strategies."""
+    """CheckpointIO to save checkpoints for HPU training strategies.
+
+    .. warning::  This is an :ref:`experimental <versioning:Experimental API>` feature.
+    """
 
     def save_checkpoint(self, checkpoint: Dict[str, Any], path: _PATH, storage_options: Optional[Any] = None) -> None:
         """Save model/training states as a checkpoint file through state-dump and file-write.
