@@ -12,11 +12,10 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 import os
-from typing import Any, List, Tuple
+from typing import Any, List, Literal, Tuple
 
 import torch.nn as nn
 from torch.optim import Optimizer
-from typing_extensions import Literal
 
 from pytorch_lightning.plugins.precision import TPUPrecisionPlugin
 
@@ -24,7 +23,7 @@ from pytorch_lightning.plugins.precision import TPUPrecisionPlugin
 class TPUBf16PrecisionPlugin(TPUPrecisionPlugin):
     """Plugin that enables bfloats on TPUs."""
 
-    precision: Literal["bf16"] = "bf16"
+    precision: Literal["bf16-mixed"] = "bf16-mixed"
 
     def connect(
         self, model: nn.Module, optimizers: List[Optimizer], lr_schedulers: List[Any]
