@@ -1,25 +1,23 @@
 import logging
 import time
 from multiprocessing import Process
-from typing import Any, Dict, Optional
+from typing import Any, Dict, Literal, Optional
 
 import requests
 import torch
-from typing_extensions import Literal
+from lightning_utilities.core.imports import RequirementCache
 
 import pytorch_lightning as pl
 from pytorch_lightning.callbacks import Callback
 from pytorch_lightning.serve.servable_module import ServableModule
-from pytorch_lightning.strategies import DDPFullyShardedNativeStrategy, DDPFullyShardedStrategy, DeepSpeedStrategy
+from pytorch_lightning.strategies import DeepSpeedStrategy, FSDPStrategy
 from pytorch_lightning.utilities.exceptions import MisconfigurationException
-from pytorch_lightning.utilities.imports import _RequirementAvailable
 from pytorch_lightning.utilities.model_helpers import is_overridden
 from pytorch_lightning.utilities.rank_zero import rank_zero_only
 
 _NOT_SUPPORTED_STRATEGIES = (
     DeepSpeedStrategy,
-    DDPFullyShardedNativeStrategy,
-    DDPFullyShardedStrategy,
+    FSDPStrategy,
 )
 
 _logger = logging.getLogger(__name__)
@@ -28,9 +26,7 @@ _logger = logging.getLogger(__name__)
 class ServableModuleValidator(Callback):
     """The ServableModuleValidator validates to validate a model correctly implement the ServableModule API.
 
-    .. warning::
-
-        This is currently an experimental feature and API changes are to be expected.
+    .. warning::  This is an :ref:`experimental <versioning:Experimental API>` feature.
 
     Arguments:
         optimization: The format in which the model should be tested while being served.
@@ -51,10 +47,10 @@ class ServableModuleValidator(Callback):
         exit_on_failure: bool = True,
     ):
         super().__init__()
-        fastapi_installed = _RequirementAvailable("fastapi")
+        fastapi_installed = RequirementCache("fastapi")
         if not fastapi_installed:
             raise ModuleNotFoundError(fastapi_installed.message)
-        uvicorn_installed = _RequirementAvailable("uvicorn")
+        uvicorn_installed = RequirementCache("uvicorn")
         if not uvicorn_installed:
             raise ModuleNotFoundError(uvicorn_installed.message)
 
