@@ -1,4 +1,4 @@
-# Copyright The Lightning team.
+# Copyright The Lightning AI team.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -12,27 +12,18 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 from lightning_fabric.strategies.registry import _StrategyRegistry
-from pytorch_lightning.strategies.bagua import BaguaStrategy  # noqa: F401
-from pytorch_lightning.strategies.colossalai import ColossalAIStrategy  # noqa: F401
 from pytorch_lightning.strategies.ddp import DDPStrategy  # noqa: F401
-from pytorch_lightning.strategies.ddp_spawn import DDPSpawnStrategy  # noqa: F401
 from pytorch_lightning.strategies.deepspeed import DeepSpeedStrategy  # noqa: F401
-from pytorch_lightning.strategies.dp import DataParallelStrategy  # noqa: F401
-from pytorch_lightning.strategies.fully_sharded import DDPFullyShardedStrategy  # noqa: F401
-from pytorch_lightning.strategies.fully_sharded_native import DDPFullyShardedNativeStrategy  # noqa: F401
-from pytorch_lightning.strategies.hivemind import HivemindStrategy  # noqa: F401
-from pytorch_lightning.strategies.horovod import HorovodStrategy  # noqa: F401
+from pytorch_lightning.strategies.fsdp import FSDPStrategy  # noqa: F401
 from pytorch_lightning.strategies.hpu_parallel import HPUParallelStrategy  # noqa: F401
 from pytorch_lightning.strategies.ipu import IPUStrategy  # noqa: F401
 from pytorch_lightning.strategies.parallel import ParallelStrategy  # noqa: F401
-from pytorch_lightning.strategies.sharded import DDPShardedStrategy  # noqa: F401
-from pytorch_lightning.strategies.sharded_spawn import DDPSpawnShardedStrategy  # noqa: F401
 from pytorch_lightning.strategies.single_device import SingleDeviceStrategy  # noqa: F401
 from pytorch_lightning.strategies.single_hpu import SingleHPUStrategy  # noqa: F401
 from pytorch_lightning.strategies.single_tpu import SingleTPUStrategy  # noqa: F401
 from pytorch_lightning.strategies.strategy import Strategy  # noqa: F401
-from pytorch_lightning.strategies.tpu_spawn import TPUSpawnStrategy  # noqa: F401
 from pytorch_lightning.strategies.utils import _call_register_strategies
+from pytorch_lightning.strategies.xla import XLAStrategy  # noqa: F401
 
 _STRATEGIES_BASE_MODULE = "pytorch_lightning.strategies"
 StrategyRegistry = _StrategyRegistry()
