@@ -1,4 +1,4 @@
-# Copyright The PyTorch Lightning team.
+# Copyright The Lightning AI team.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -11,12 +11,13 @@
 # WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 # See the License for the specific language governing permissions and
 # limitations under the License.
+import logging
 import os
 import tempfile
-from collections import UserList
+from contextlib import suppress
 from dataclasses import dataclass
 from multiprocessing.queues import SimpleQueue
-from typing import Any, Callable, Dict, NamedTuple, Optional
+from typing import Any, Callable, Dict, List, Literal, NamedTuple, Optional
 
 import numpy as np
 import torch
@@ -24,18 +25,19 @@ import torch.backends.cudnn
 import torch.multiprocessing as mp
 from lightning_utilities.core.apply_func import apply_to_collection
 from torch import Tensor
-from typing_extensions import Literal
 
 import pytorch_lightning as pl
-from lightning_fabric.strategies.launchers.base import _Launcher
 from lightning_fabric.strategies.launchers.multiprocessing import _check_bad_cuda_fork
 from lightning_fabric.utilities import move_data_to_device
-from lightning_fabric.utilities.imports import _TORCH_GREATER_EQUAL_1_11
 from lightning_fabric.utilities.seed import _collect_rng_states, _set_rng_states
 from lightning_fabric.utilities.types import _PATH
+from pytorch_lightning.strategies.launchers.launcher import _Launcher
+from pytorch_lightning.trainer.connectors.signal_connector import _SIGNUM
 from pytorch_lightning.trainer.states import TrainerFn, TrainerState
 from pytorch_lightning.utilities.rank_zero import rank_zero_debug
 
+log = logging.getLogger(__name__)
+
 
 class _MultiProcessingLauncher(_Launcher):
     r"""Launches processes that run a given function in parallel, and joins them all at the end.
@@ -61,7 +63,7 @@ class _MultiProcessingLauncher(_Launcher):
     """
 
     def __init__(
-        self, strategy: "pl.strategies.DDPSpawnStrategy", start_method: Literal["spawn", "fork", "forkserver"] = "spawn"
+        self, strategy: "pl.strategies.ParallelStrategy", start_method: Literal["spawn", "fork", "forkserver"] = "spawn"
     ) -> None:
         self._strategy = strategy
         self._start_method = start_method
@@ -70,6 +72,7 @@ class _MultiProcessingLauncher(_Launcher):
                 f"The start method '{self._start_method}' is not available on this platform. Available methods are:"
                 f" {', '.join(mp.get_all_start_methods())}"
             )
+        self.procs: List[mp.Process] = []
 
     @property
     def is_interactive_compatible(self) -> bool:
@@ -110,12 +113,17 @@ class _MultiProcessingLauncher(_Launcher):
         else:
             process_args = [trainer, function, args, kwargs, return_queue]
 
-        mp.start_processes(
+        process_context = mp.start_processes(
             self._wrapping_function,
             args=process_args,
             nprocs=self._strategy.num_processes,
             start_method=self._start_method,
+            join=False,  # we will join ourselves to get the process references
         )
+        self.procs = process_context.processes
+        while not process_context.join():
+            pass
+
         worker_output = return_queue.get()
         if trainer is None:
             return worker_output
@@ -135,7 +143,7 @@ class _MultiProcessingLauncher(_Launcher):
     ) -> None:
         if global_states:
             global_states.restore()
-        self._strategy._local_rank = process_idx
+        os.environ["LOCAL_RANK"] = str(process_idx)
         results = function(*args, **kwargs)
 
         if trainer is not None:
@@ -153,13 +161,15 @@ class _MultiProcessingLauncher(_Launcher):
         # load last weights
         if worker_output.weights_path is not None:
             ckpt = self._strategy.checkpoint_io.load_checkpoint(worker_output.weights_path)
-            trainer.lightning_module.load_state_dict(ckpt)
+            # choose non-strict loading of parameters on the main process, because the model's composition
+            # could have changed in the worker process (layers added or removed)
+            trainer.lightning_module.load_state_dict(ckpt, strict=False)
             self._strategy.checkpoint_io.remove_checkpoint(worker_output.weights_path)
 
         trainer.state = worker_output.trainer_state
 
         # get the `callback_metrics` and set it to the trainer
-        self.get_from_queue(trainer, worker_output.extra)
+        self.update_main_process_results(trainer, worker_output.extra)
 
     def _collect_rank_zero_results(self, trainer: "pl.Trainer", results: Any) -> Optional["_WorkerOutput"]:
         rank_zero_debug("Collecting results from rank 0 process.")
@@ -183,9 +193,8 @@ class _MultiProcessingLauncher(_Launcher):
             weights_path = os.path.join(tempfile.mkdtemp(), ".temp.ckpt")
             self._strategy.checkpoint_io.save_checkpoint(state_dict, weights_path)
 
-        # adds the `callback_metrics` to the queue
-        extra = _FakeQueue()
-        self.add_to_queue(trainer, extra)
+        # add extra result data from trainer to send to main process
+        extra = self.get_extra_results(trainer)
 
         return _WorkerOutput(best_model_path, weights_path, trainer.state, results, extra)
 
@@ -196,46 +205,49 @@ class _MultiProcessingLauncher(_Launcher):
             if _is_deferred(self._strategy.lightning_module):
                 raise NotImplementedError(
                     f"The `{type(self._strategy).__name__}` strategy does not support `torchdistx`'s deferred"
-                    f" initialization."
+                    f" initialization when `start_method='spawn'`."
                 )
 
-    def add_to_queue(self, trainer: "pl.Trainer", queue: "_FakeQueue") -> None:
-        """Appends the :attr:`trainer.callback_metrics` dictionary to the given queue. To avoid issues with memory
-        sharing, we cast the data to numpy.
+    def get_extra_results(self, trainer: "pl.Trainer") -> Dict[str, Any]:
+        """Gather extra state from the Trainer and return it as a dictionary for sending back to the main process.
+        To avoid issues with memory sharing, we cast the data to numpy.
 
         Args:
             trainer: reference to the Trainer.
-            queue: the instance of the queue to append the data.
+
+        Returns:
+            A dictionary with items to send back to the main process where :meth:`update_main_process_results` will
+            process this output.
         """
         callback_metrics: dict = apply_to_collection(
             trainer.callback_metrics, Tensor, lambda x: x.cpu().numpy()
         )  # send as numpy to avoid issues with memory sharing
-        queue.put(callback_metrics)
+        return {"callback_metrics": callback_metrics}
 
-    def get_from_queue(self, trainer: "pl.Trainer", queue: "_FakeQueue") -> None:
+    def update_main_process_results(self, trainer: "pl.Trainer", extra: Dict[str, Any]) -> None:
         """Retrieve the :attr:`trainer.callback_metrics` dictionary from the given queue. To preserve consistency,
         we cast back the data to ``torch.Tensor``.
 
         Args:
             trainer: reference to the Trainer.
-            queue: the instance of the queue from where to get the data.
+            extra: A dictionary with trainer state that was sent from the worker process and needs to be restored
+                on the current trainer.
         """
-        # NOTE: `add_to_queue` needs to be called before
-        callback_metrics: dict = queue.get()
+        # NOTE: `get_extra_results` needs to be called before
+        callback_metrics = extra["callback_metrics"]
         trainer.callback_metrics.update(apply_to_collection(callback_metrics, np.ndarray, lambda x: torch.tensor(x)))
 
+    def kill(self, signum: _SIGNUM) -> None:
+        for proc in self.procs:
+            if proc.is_alive() and proc.pid is not None:
+                log.info(f"pid {os.getpid()} killing {proc.pid} with {signum}")
+                with suppress(ProcessLookupError):
+                    os.kill(proc.pid, signum)
 
-class _FakeQueue(UserList):
-    """Simulates a :class:`torch.multiprocessing.queue.SimpleQueue` interface using the Python list."""
-
-    def get(self) -> Any:
-        return self.pop(0)
-
-    def put(self, item: Any) -> None:
-        self.append(item)
-
-    def empty(self) -> bool:
-        return len(self) == 0
+    def __getstate__(self) -> Dict:
+        state = self.__dict__.copy()
+        state["procs"] = []  # SpawnProcess can't be pickled
+        return state
 
 
 class _WorkerOutput(NamedTuple):
@@ -243,7 +255,7 @@ class _WorkerOutput(NamedTuple):
     weights_path: Optional[_PATH]
     trainer_state: TrainerState
     trainer_results: Any
-    extra: _FakeQueue
+    extra: Dict[str, Any]
 
 
 @dataclass
@@ -273,21 +285,17 @@ class _GlobalStateSnapshot:
     def capture(cls) -> "_GlobalStateSnapshot":
         """Capture a few global states from torch, numpy, etc., that we want to restore in a spawned worker
         process."""
-        warn_only = torch.is_deterministic_algorithms_warn_only_enabled() if _TORCH_GREATER_EQUAL_1_11 else False
         return cls(
             use_deterministic_algorithms=torch.are_deterministic_algorithms_enabled(),
-            use_deterministic_algorithms_warn_only=warn_only,
+            use_deterministic_algorithms_warn_only=torch.is_deterministic_algorithms_warn_only_enabled(),
             cudnn_benchmark=torch.backends.cudnn.benchmark,
             rng_states=_collect_rng_states(),
         )
 
     def restore(self) -> None:
         """Restores all globals to the values captured in the :meth:`capture` method."""
-        if _TORCH_GREATER_EQUAL_1_11:
-            torch.use_deterministic_algorithms(
-                self.use_deterministic_algorithms, warn_only=self.use_deterministic_algorithms_warn_only
-            )
-        else:
-            torch.use_deterministic_algorithms(self.use_deterministic_algorithms)
+        torch.use_deterministic_algorithms(
+            self.use_deterministic_algorithms, warn_only=self.use_deterministic_algorithms_warn_only
+        )
         torch.backends.cudnn.benchmark = self.cudnn_benchmark
         _set_rng_states(self.rng_states)
