@@ -1,4 +1,4 @@
-# Copyright The PyTorch Lightning team.
+# Copyright The Lightning AI team.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -13,35 +13,28 @@
 # limitations under the License.
 import inspect
 from dataclasses import fields
-from typing import Any, Dict, Generator, Iterable, Mapping, Optional, Tuple, Union
+from typing import Any, Dict, Generator, Iterable, Mapping, Optional, Sized, Tuple, Union
 
 import torch
 from lightning_utilities.core.apply_func import is_dataclass_instance
+from lightning_utilities.core.rank_zero import rank_prefixed_message
 from torch import Tensor
-from torch.utils.data import (
-    BatchSampler,
-    DataLoader,
-    Dataset,
-    IterableDataset,
-    RandomSampler,
-    Sampler,
-    SequentialSampler,
-)
+from torch.utils.data import BatchSampler, DataLoader, IterableDataset, RandomSampler, Sampler, SequentialSampler
+from typing_extensions import TypeGuard
 
 import pytorch_lightning as pl
-from lightning_fabric.utilities.data import _reinstantiate_wrapped_cls, _replace_value_in_saved_args
-from lightning_fabric.utilities.data import has_iterable_dataset as new_has_iterable_dataset
-from lightning_fabric.utilities.data import has_len as new_has_len
-from pytorch_lightning.overrides.distributed import IndexBatchSamplerWrapper
+from lightning_fabric.utilities.data import (
+    _reinstantiate_wrapped_cls,
+    _replace_value_in_saved_args,
+    has_iterable_dataset,
+    sized_len,
+)
+from pytorch_lightning.overrides.distributed import _IndexBatchSamplerWrapper
 from pytorch_lightning.trainer.states import RunningStage
-from pytorch_lightning.trainer.supporters import CombinedLoader
-from pytorch_lightning.utilities.auto_restart import CaptureIterableDataset, CaptureMapDataset, FastForwardSampler
-from pytorch_lightning.utilities.enums import _FaultTolerantMode
 from pytorch_lightning.utilities.exceptions import MisconfigurationException
-from pytorch_lightning.utilities.rank_zero import rank_zero_deprecation, rank_zero_warn, WarningCache
+from pytorch_lightning.utilities.rank_zero import rank_zero_warn, WarningCache
 
-# might be supported in later releases, see https://github.com/python/mypy/pull/13297
-BType = Union[Tensor, str, Mapping[Any, "BType"], Iterable["BType"]]  # type: ignore[misc]
+BType = Union[Tensor, str, Mapping[Any, "BType"], Iterable["BType"]]
 
 warning_cache = WarningCache()
 
@@ -59,7 +52,7 @@ def _extract_batch_size(batch: BType) -> Generator[Optional[int], None, None]:
         for sample in batch:
             yield from _extract_batch_size(sample)
     elif is_dataclass_instance(batch):
-        for field in fields(batch):
+        for field in fields(batch):  # type: ignore[arg-type]
             yield from _extract_batch_size(getattr(batch, field.name))
     else:
         yield None
@@ -96,41 +89,41 @@ def extract_batch_size(batch: BType) -> int:
 
 
 def has_len_all_ranks(
-    dataloader: Union[DataLoader, CombinedLoader],
+    dataloader: object,
     strategy: "pl.strategies.Strategy",
-    model: Union["pl.LightningModule", "pl.LightningDataModule"],
-) -> bool:
-    """Checks if a given Dataloader has ``__len__`` method implemented i.e. if it is a finite dataloader or
-    infinite dataloader."""
-    try:
-        local_length = len(dataloader)  # type: ignore [arg-type] # we are checking with duck-typing
-        total_length = strategy.reduce(torch.tensor(local_length, device=strategy.root_device), reduce_op="sum")
-
-        if total_length == 0:
-            rank_zero_warn(
-                f"Total length of `{dataloader.__class__.__name__}` across ranks is zero."
-                " Please make sure this was your intention."
+    allow_zero_length_dataloader_with_multiple_devices: bool = False,
+) -> TypeGuard[Sized]:
+    """Checks if a given object has ``__len__`` method implemented on all aranks."""
+    local_length = sized_len(dataloader)
+    has_len = True
+    if local_length is None:
+        # if one rank does not define a length, the reduction after would fail, default to 0
+        local_length = 0
+        has_len = False
+    total_length = strategy.reduce(torch.tensor(local_length, device=strategy.root_device), reduce_op="sum")
+    if total_length == 0:
+        rank_zero_warn(
+            f"Total length of `{type(dataloader).__name__}` across ranks is zero."
+            " Please make sure this was your intention."
+        )
+    if total_length > 0 and local_length == 0:
+        dataloader_cls_name = type(dataloader).__name__
+        if not has_len:
+            raise RuntimeError(
+                rank_prefixed_message(f"The `{dataloader_cls_name}` does not define a length.", strategy.global_rank)
             )
-        if total_length > 0 and local_length == 0:
-            if model.allow_zero_length_dataloader_with_multiple_devices:
-                rank_zero_warn(
-                    f"Total length of `{dataloader.__class__.__name__}` across ranks is zero, but local rank has zero"
-                    " length. Please be cautious of uneven batch length."
-                )
-                has_len = False
-            else:
-                raise MisconfigurationException(
-                    f"`{dataloader.__class__.__name__}` within local rank has zero length."
-                    " Please make sure that it returns at least 1 batch."
-                )
-        else:
-            has_len = True
-
-    except (TypeError, NotImplementedError):
+        if not allow_zero_length_dataloader_with_multiple_devices:
+            raise RuntimeError(
+                f"`{dataloader_cls_name}` within local rank has zero length."
+                " Please make sure that it returns at least 1 batch."
+            )
+        rank_zero_warn(
+            f"Total length of `{dataloader_cls_name}` across ranks is zero, but local rank has zero"
+            " length. Please be cautious of uneven batch length."
+        )
         has_len = False
 
-    # we are checking using lightning_fabric, which doesn't know CombinedLoader
-    if has_len and new_has_iterable_dataset(dataloader):  # type: ignore [arg-type]
+    if has_len and has_iterable_dataset(dataloader):
         rank_zero_warn(
             "Your `IterableDataset` has `__len__` defined."
             " In combination with multi-process data loading (when num_workers > 1),"
@@ -140,18 +133,6 @@ def has_len_all_ranks(
     return has_len
 
 
-def get_len(dataloader: Union[DataLoader, Dataset]) -> Union[int, float]:
-    """Return the length of the given DataLoader.
-
-    If ``__len__`` method is not implemented, return float('inf').
-    """
-
-    if new_has_len(dataloader):
-        return len(dataloader)  # type: ignore [arg-type]
-
-    return float("inf")
-
-
 def _update_dataloader(
     dataloader: DataLoader, sampler: Union[Sampler, Iterable], mode: Optional[RunningStage] = None
 ) -> DataLoader:
@@ -252,11 +233,6 @@ def _get_dataloader_init_args_and_kwargs(
                 "class, add the `__init__` arguments or allow passing `**kwargs`"
             )
 
-    if _FaultTolerantMode.detect_current_mode().is_automatic:
-        dl_args, dl_kwargs = _apply_fault_tolerant_automatic_capture_dataset_wrapper(
-            was_wrapped, arg_names, dl_args, dl_kwargs
-        )
-
     return dl_args, dl_kwargs
 
 
@@ -269,22 +245,21 @@ def _dataloader_init_kwargs_resolve_sampler(
     """This function is used to handle the sampler, batch_sampler arguments associated within a DataLoader for its
     re-instantiation.
 
-    If the dataloader is being used for prediction, the sampler will be wrapped into an `IndexBatchSamplerWrapper`, so
-    Lightning can keep track of its indices. If fault tolerant training is enabled, the sampler will be wrapped into a
-    `FastForwardSampler`.
+    If the dataloader is being used for prediction, the sampler will be wrapped into an `_IndexBatchSamplerWrapper`, so
+    Lightning can keep track of its indices.
 
     If there are multiple devices in IPU mode, it is necessary to disallow BatchSampler that isn't instantiated
     automatically, since `poptorch.DataLoader` will try to increase the batch_size
     """
-    fault_tolerant_mode = _FaultTolerantMode.detect_current_mode()
-    batch_sampler = getattr(dataloader, "batch_sampler")
     is_predicting = mode == RunningStage.PREDICTING
+    batch_sampler = getattr(dataloader, "batch_sampler")
+    batch_sampler_cls = type(batch_sampler)
 
     if batch_sampler is not None:
         if disallow_batch_sampler:
             # Check that we don't have a PyTorch default batch sampler that was instantiated in DataLoader __init__
             if not (
-                type(batch_sampler) is BatchSampler
+                batch_sampler_cls is BatchSampler
                 and batch_sampler.sampler == sampler
                 and dataloader.batch_size == batch_sampler.batch_size
             ):
@@ -292,8 +267,7 @@ def _dataloader_init_kwargs_resolve_sampler(
                     "It is not possible to have a batch sampler in your dataloader, "
                     "when running on multiple IPU devices."
                 )
-        elif type(batch_sampler) is not BatchSampler or is_predicting:
-            batch_sampler_cls = type(batch_sampler)
+        elif batch_sampler_cls is not BatchSampler or is_predicting:
             if hasattr(batch_sampler, "__pl_saved_args"):
                 args = batch_sampler.__pl_saved_args
                 kwargs = batch_sampler.__pl_saved_kwargs
@@ -347,12 +321,9 @@ def _dataloader_init_kwargs_resolve_sampler(
                     ) from e
 
             if is_predicting:
-                batch_sampler = IndexBatchSamplerWrapper(batch_sampler)
-
-            if fault_tolerant_mode.is_automatic:
-                fast_forward_sampler = batch_sampler = FastForwardSampler(batch_sampler)
-                fast_forward_sampler.setup(dataloader_batch_size=1)
+                batch_sampler = _IndexBatchSamplerWrapper(batch_sampler)
 
+            # batch_sampler option is mutually exclusive with batch_size, shuffle, sampler, and drop_last
             return {
                 "sampler": None,
                 "shuffle": False,
@@ -361,48 +332,9 @@ def _dataloader_init_kwargs_resolve_sampler(
                 "drop_last": False,
             }
 
-    if fault_tolerant_mode.is_automatic:
-        fast_forward_sampler = sampler = FastForwardSampler(sampler)
-        fast_forward_sampler.setup(dataloader_batch_size=dataloader.batch_size)
-
     return {"sampler": sampler, "shuffle": False, "batch_sampler": None}
 
 
-def _wrap_with_capture_dataset(dataset: Dataset) -> Dataset:
-    if isinstance(dataset, IterableDataset):
-        # wrap the `IterableDataset` into a `CaptureIterableDataset` to record sampler states.
-        return CaptureIterableDataset(dataset=dataset)
-    if get_len(dataset) != float("inf"):
-        return CaptureMapDataset(dataset=dataset)
-    raise RuntimeError("This shouldn't happen, please open an issue on Lightning Github repository.")
-
-
-def _apply_fault_tolerant_automatic_capture_dataset_wrapper(
-    was_wrapped: bool, arg_names: Tuple[str, ...], dl_args: Tuple[Any, ...], dl_kwargs: Dict[str, Any]
-) -> Tuple[Tuple[str, ...], Dict[str, Any]]:
-    if "dataset" in dl_kwargs:
-        dl_kwargs["dataset"] = _wrap_with_capture_dataset(dl_kwargs["dataset"])
-    elif "dataset" in arg_names:
-        dataset_idx = arg_names.index("dataset")
-        dataset = _wrap_with_capture_dataset(dl_args[dataset_idx])
-        dl_args = dl_args[:dataset_idx] + (dataset,) + dl_args[dataset_idx + 1 :]
-    else:
-        if was_wrapped:
-            avoid_message = (
-                " To avoid this, either pass `DataLoader(dataset=your_dataset)` or the positional dataset argument"
-                " `DataLoader(your_dataset, ...)`."
-            )
-        else:
-            avoid_message = " To avoid this, define `self.dataset = dataset` inside your DataLoader's `__init__`."
-
-        raise MisconfigurationException(
-            "You enabled automatic Fault Tolerant mode, but we were not able to replace your dataset"
-            " with Fault Tolerant wrapper, because you have a custom DataLoader." + avoid_message
-        )
-
-    return dl_args, dl_kwargs
-
-
 def _is_dataloader_shuffled(dataloader: object) -> bool:
     if hasattr(dataloader, "__pl_saved_kwargs"):
         # this attribute is not part of PyTorch's DataLoader, but could have been set by
@@ -411,7 +343,7 @@ def _is_dataloader_shuffled(dataloader: object) -> bool:
             return dataloader.__pl_saved_kwargs["shuffle"]
         if "shuffle" in dataloader.__pl_saved_arg_names:
             return dataloader.__pl_saved_args[dataloader.__pl_saved_arg_names.index("shuffle")]
-    if isinstance(dataloader.dataset, IterableDataset):
+    if hasattr(dataloader, "dataset") and isinstance(dataloader.dataset, IterableDataset):
         # shuffling is useless with iterable datasets
         return False
     if not hasattr(dataloader, "sampler"):
@@ -421,19 +353,3 @@ def _is_dataloader_shuffled(dataloader: object) -> bool:
     if isinstance(sampler, SequentialSampler):
         return False
     return isinstance(sampler, RandomSampler)
-
-
-def has_iterable_dataset(*args: Any, **kwargs: Any) -> Any:
-    rank_zero_deprecation(
-        "`pytorch_lightning.utilities.data.has_iterable_dataset` has been deprecated in v1.8.0 and will be"
-        " removed in v2.0.0. Please use `lightning_fabric.utilities.data.has_iterable_dataset` instead."
-    )
-    return new_has_iterable_dataset(*args, **kwargs)
-
-
-def has_len(*args: Any, **kwargs: Any) -> Any:
-    rank_zero_deprecation(
-        "`pytorch_lightning.utilities.data.has_len` has been deprecated in v1.8.0 and will be"
-        " removed in v2.0.0. Please use `lightning_fabric.utilities.data.has_len` instead."
-    )
-    return new_has_len(*args, **kwargs)
